{#
    Sphinx layout template for the Solarized theme which is shamelessly
    based on the official Haiku theme.
#}

{%- extends "basic/layout.html" %}

{# do not display relbars #}
{% block relbar1 %}{% endblock %}
{% block relbar2 %}{% endblock %}



{% macro nav() %}
    <p>
        {%- if prev %}
        «&#160;&#160;<a href="{{ prev.link|e }}">{{ prev.title }}</a>
        &#160;&#160;::&#160;&#160;
        {%- endif %}
        <a class="uplink" href="{{ pathto(master_doc) }}">{{ _('Contents') }}</a>
        {%- if next %}
        &#160;&#160;::&#160;&#160;
        <a href="{{ next.link|e }}">{{ next.title }}</a>&#160;&#160;»
        {%- endif %}
    </p>
{% endmacro %}



{% block content %}
    <div class="header" role="banner">
        <a href="{{ pathto('index') }}">
            <img    class="rightlogo"
                    src="{{ pathto('_static/logo.png', 1) }}"
                    alt="Logo"
                    style="width: 75px; height: 75px;"
            >
        </a>
        <h1 class="heading">
            <a href="{{ pathto('index') }}">
                <span>{{ project }}</span>
            </a>
        </h1>
        <h2 class="heading">
            <span>{{ title|striptags|e }}</span>
        </h2>
    </div>
    <div class="topnav" role="navigation" aria-label="top navigation">
    {{ nav() }}
    </div>
    <div class="content">
        {#{%- if display_toc %}
        <div id="toc">
            <h3>{{ _('Table of Contents') }}</h3>
            {{ toc }}
        </div>
        {%- endif %}#}
        {% block body %}{% endblock %}
    </div>
    <div class="bottomnav" role="navigation" aria-label="bottom navigation">
        {{ nav() }}
    </div>
{% endblock %}



{%- block footer %}
    <div class="footer" role="contentinfo">

        &#169; Copyright {{ copyright }}. Last updated on {{ last_updated }}.
        <br>
        Created using <a href="http://sphinx-doc.org/">Sphinx</a> {{ sphinx_version }}
        with <a href="https://github.com/matthias-stein/sphi_sola/">sphi_sola</a> theme.

    </div>
{%- endblock %}
